"""
/***************************************************************************
ODTraceDialog
								A QGIS plugin
Trace des flux OD
							-------------------
		begin                : 2012-02-17
		copyright            : (C) 2012 by Gregoire Piffault
		email                : gpiffault@systra.com
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/
"""

import os
from PyQt4 import QtCore, QtGui
from qgis.gui import QgsEncodingFileDialog

from ui_odtrace import Ui_ODTrace
# create the dialog for zoom to point
class ODTraceDialog(QtGui.QDialog):
	def __init__(self, pointlayers):
		QtGui.QDialog.__init__(self)
		# Set up the user interface from Designer.
		self.ui = Ui_ODTrace()
		self.ui.setupUi(self)
		# Vars
		self.pointlayers = pointlayers
		self.encoding = "CP1252"
		self.outshape = None
		# Connections
		self.ui.inshape.currentIndexChanged.connect(self.check_inshape)
		self.ui.open_influx.clicked.connect(self.open_influx)
		self.ui.save_outshape.clicked.connect(self.save_outshape)
		# Populate point layer names
		self.ui.inshape.clear()
		self.ui.inshape.addItems([layer.name() for layer in self.pointlayers])
	
	def accept(self):
		# Inputs check
		if self.ui.inshape.currentIndex() == -1:
			QtGui.QMessageBox.warning(self, "OD Trace", "Pas de couche de points selectionnee")
			return False
		if not os.access(unicode(self.ui.influx.text()), os.R_OK):
			QtGui.QMessageBox.warning(self, "OD Trace", "Le fichier de flux n'est pas accessible en lecture")
			return False
		if self.ui.outshape.text() == "":
			QtGui.QMessageBox.warning(self, "OD Trace", "Specifiez un fichier shape de sortie")
			return False
		# Fetch values
		self.selected_field = self.ui.inshape_field.currentIndex()
		self.outshape = unicode(self.ui.outshape.text())
		try:
			self.influx_threshold = float(self.ui.influx_threshold.text())
		except:
			self.influx_threshold = 0.0
		QtGui.QDialog.accept(self)
	
	def open_influx(self):
		filename = QtGui.QFileDialog.getOpenFileName(self, "Open file", "", "Tab separated values (*.txt *.tsv *.tab)")
		if filename:
			self.ui.influx.clear()
			self.ui.influx.setText(filename)
	
	def save_outshape(self):
		# fileDialog = QgsEncodingFileDialog(self, "Save file", "", "Shapefiles (*.shp)", "CP1252")
		# fileDialog.setDefaultSuffix("shp")
		# fileDialog.setFileMode(fileDialog.AnyFile)
		# fileDialog.setAcceptMode(fileDialog.AcceptSave)
		# if fileDialog.exec_() == fileDialog.Accepted:
			# self.ui.outshape.clear()
			# self.encoding = fileDialog.encoding()
			# self.outshape = fileDialog.selectedFiles()[0]
			# self.ui.outshape.setText(self.outshape)
		filename = QtGui.QFileDialog.getSaveFileName(self, "Save file", "", "Shapefiles (*.shp)")
		if filename:
			self.ui.outshape.clear()
			self.ui.outshape.setText(filename)
	
	def check_inshape(self):
		selected_index = self.ui.inshape.currentIndex()
		if selected_index != -1:
			self.selected_pointlayer = self.pointlayers[selected_index]
			self.ui.inshape_field.clear()
			self.ui.inshape_field.addItems([field.name() for field in self.selected_pointlayer.dataProvider().fields().values()])
